Index — intake_spark 0.0.0+3.gadf091e.dirty documentation

# Index

R | S | T

## R

read() (intake_spark.spark_sources.SparkDataFrame method) (intake_spark.spark_sources.SparkRDD method) | read_partition() (intake_spark.spark_sources.SparkDataFrame method) (intake_spark.spark_sources.SparkRDD method)

## S

SparkDataFrame (class in intake_spark.spark_sources) | SparkRDD (class in intake_spark.spark_sources) SparkTablesCatalog (class in intake_spark.spark_cat)

## T

to_spark() (intake_spark.spark_sources.SparkDataFrame method) (intake_spark.spark_sources.SparkRDD method)